netapp_ontap.models.volume_space API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_space`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeSpaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET`

    The available space, in bytes.

  `block_storage_inactive_user_data GET`

    The size that is physically used in the block storage of the volume and has a cold temperature. In bytes. This parameter is only supported if the volume is in an aggregate that is either attached to a cloud store or could be attached to a cloud store.

  `capacity_tier_footprint GET`

    Space used by capacity tier for this volume in the FabricPool aggregate, in bytes.

  `footprint GET`

    Data used for this volume in the aggregate, in bytes.

  `local_tier_footprint GET`

    Space used by the local tier for this volume in the aggregate, in bytes.

  `logical_space GET POST PATCH`

    The logical_space field of the volume_space.

  `metadata GET`

    Space used by the volume metadata in the aggregate, in bytes.

  `over_provisioned GET`

    The amount of space not available for this volume in the aggregate, in bytes.

  `performance_tier_footprint GET`

    Space used by the performance tier for this volume in the FabricPool aggregate, in bytes.

  `size GET POST PATCH`

    Total provisioned size. The default size is equal to the minimum size of 20MB, in bytes.

  `snapshot GET POST PATCH`

    The snapshot field of the volume_space.

  `total_footprint GET`

    Data and metadata used for this volume in the aggregate, in bytes.

  `used GET`

    The virtual space used (includes volume reserves) before storage efficiency, in bytes.